<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\ClaseVehiculo;

class ClaseVehiculoPolicy
{

    /**
     * Determine if the given user can view the clase_vehiculo.
     *
     * @param UserPolicy $user
     * @param ClaseVehiculo $clase_vehiculo
     *
     * @return bool
     */
    public function view(UserPolicy $user, ClaseVehiculo $clase_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.clase_vehiculo.view') && $user->isAdmin()) {
            return true;
        }

        return $clase_vehiculo->user_id == user_id() && $clase_vehiculo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a clase_vehiculo.
     *
     * @param UserPolicy $user
     * @param ClaseVehiculo $clase_vehiculo
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.clase_vehiculo.create');
    }

    /**
     * Determine if the given user can update the given clase_vehiculo.
     *
     * @param UserPolicy $user
     * @param ClaseVehiculo $clase_vehiculo
     *
     * @return bool
     */
    public function update(UserPolicy $user, ClaseVehiculo $clase_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.clase_vehiculo.edit') && $user->isAdmin()) {
            return true;
        }

        return $clase_vehiculo->user_id == user_id() && $clase_vehiculo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given clase_vehiculo.
     *
     * @param UserPolicy $user
     * @param ClaseVehiculo $clase_vehiculo
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ClaseVehiculo $clase_vehiculo)
    {
        return $clase_vehiculo->user_id == user_id() && $clase_vehiculo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given clase_vehiculo.
     *
     * @param UserPolicy $user
     * @param ClaseVehiculo $clase_vehiculo
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ClaseVehiculo $clase_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.clase_vehiculo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given clase_vehiculo.
     *
     * @param UserPolicy $user
     * @param ClaseVehiculo $clase_vehiculo
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ClaseVehiculo $clase_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.clase_vehiculo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
