<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\Factura;

class FacturaPolicy
{

    /**
     * Determine if the given user can view the factura.
     *
     * @param UserPolicy $user
     * @param Factura $factura
     *
     * @return bool
     */
    public function view(UserPolicy $user, Factura $factura)
    {
        if ($user->canDo('ing_vhiculo.factura.view') && $user->isAdmin()) {
            return true;
        }

        return $factura->user_id == user_id() && $factura->user_type == user_type();
    }

    /**
     * Determine if the given user can create a factura.
     *
     * @param UserPolicy $user
     * @param Factura $factura
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.factura.create');
    }

    /**
     * Determine if the given user can update the given factura.
     *
     * @param UserPolicy $user
     * @param Factura $factura
     *
     * @return bool
     */
    public function update(UserPolicy $user, Factura $factura)
    {
        if ($user->canDo('ing_vhiculo.factura.edit') && $user->isAdmin()) {
            return true;
        }

        return $factura->user_id == user_id() && $factura->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given factura.
     *
     * @param UserPolicy $user
     * @param Factura $factura
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Factura $factura)
    {
        return $factura->user_id == user_id() && $factura->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given factura.
     *
     * @param UserPolicy $user
     * @param Factura $factura
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Factura $factura)
    {
        if ($user->canDo('ing_vhiculo.factura.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given factura.
     *
     * @param UserPolicy $user
     * @param Factura $factura
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Factura $factura)
    {
        if ($user->canDo('ing_vhiculo.factura.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
