<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\InfoFacturas;

class InfoFacturasPolicy
{

    /**
     * Determine if the given user can view the info_facturas.
     *
     * @param UserPolicy $user
     * @param InfoFacturas $info_facturas
     *
     * @return bool
     */
    public function view(UserPolicy $user, InfoFacturas $info_facturas)
    {
        if ($user->canDo('ing_vhiculo.info_facturas.view') && $user->isAdmin()) {
            return true;
        }

        return $info_facturas->user_id == user_id() && $info_facturas->user_type == user_type();
    }

    /**
     * Determine if the given user can create a info_facturas.
     *
     * @param UserPolicy $user
     * @param InfoFacturas $info_facturas
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.info_facturas.create');
    }

    /**
     * Determine if the given user can update the given info_facturas.
     *
     * @param UserPolicy $user
     * @param InfoFacturas $info_facturas
     *
     * @return bool
     */
    public function update(UserPolicy $user, InfoFacturas $info_facturas)
    {
        if ($user->canDo('ing_vhiculo.info_facturas.edit') && $user->isAdmin()) {
            return true;
        }

        return $info_facturas->user_id == user_id() && $info_facturas->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given info_facturas.
     *
     * @param UserPolicy $user
     * @param InfoFacturas $info_facturas
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, InfoFacturas $info_facturas)
    {
        return $info_facturas->user_id == user_id() && $info_facturas->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given info_facturas.
     *
     * @param UserPolicy $user
     * @param InfoFacturas $info_facturas
     *
     * @return bool
     */
    public function verify(UserPolicy $user, InfoFacturas $info_facturas)
    {
        if ($user->canDo('ing_vhiculo.info_facturas.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given info_facturas.
     *
     * @param UserPolicy $user
     * @param InfoFacturas $info_facturas
     *
     * @return bool
     */
    public function approve(UserPolicy $user, InfoFacturas $info_facturas)
    {
        if ($user->canDo('ing_vhiculo.info_facturas.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
