<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\Tarifa;

class TarifaPolicy
{

    /**
     * Determine if the given user can view the tarifa.
     *
     * @param UserPolicy $user
     * @param Tarifa $tarifa
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tarifa $tarifa)
    {
        if ($user->canDo('ing_vhiculo.tarifa.view') && $user->isAdmin()) {
            return true;
        }

        return $tarifa->user_id == user_id() && $tarifa->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tarifa.
     *
     * @param UserPolicy $user
     * @param Tarifa $tarifa
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.tarifa.create');
    }

    /**
     * Determine if the given user can update the given tarifa.
     *
     * @param UserPolicy $user
     * @param Tarifa $tarifa
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tarifa $tarifa)
    {
        if ($user->canDo('ing_vhiculo.tarifa.edit') && $user->isAdmin()) {
            return true;
        }

        return $tarifa->user_id == user_id() && $tarifa->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tarifa.
     *
     * @param UserPolicy $user
     * @param Tarifa $tarifa
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tarifa $tarifa)
    {
        return $tarifa->user_id == user_id() && $tarifa->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tarifa.
     *
     * @param UserPolicy $user
     * @param Tarifa $tarifa
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tarifa $tarifa)
    {
        if ($user->canDo('ing_vhiculo.tarifa.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tarifa.
     *
     * @param UserPolicy $user
     * @param Tarifa $tarifa
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tarifa $tarifa)
    {
        if ($user->canDo('ing_vhiculo.tarifa.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
