<?php

namespace Olger\IngVhiculo\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Olger\IngVhiculo\Models\IngVhiculo;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Olger\IngVhiculo\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/ing_vhiculo/camabaja/*')) {
            Route::bind('camabaja', function ($camabaja) {
                $camabajarepo = $this->app->make('Olger\IngVhiculo\Interfaces\CamabajaRepositoryInterface');
                return $camabajarepo->findorNew($camabaja);
            });
        }
        if (Request::is('*/ing_vhiculo/descuento/*')) {
            Route::bind('descuento', function ($descuento) {
                $descuentorepo = $this->app->make('Olger\IngVhiculo\Interfaces\DescuentoRepositoryInterface');
                return $descuentorepo->findorNew($descuento);
            });
        }
        if (Request::is('*/ing_vhiculo/tarifa/*')) {
            Route::bind('tarifa', function ($tarifa) {
                $tarifarepo = $this->app->make('Olger\IngVhiculo\Interfaces\TarifaRepositoryInterface');
                return $tarifarepo->findorNew($tarifa);
            });
        }
        if (Request::is('*/ing_vhiculo/clase_vehiculo/*')) {
            Route::bind('clase_vehiculo', function ($clase_vehiculo) {
                $clase_vehiculorepo = $this->app->make('Olger\IngVhiculo\Interfaces\ClaseVehiculoRepositoryInterface');
                return $clase_vehiculorepo->findorNew($clase_vehiculo);
            });
        }
        if (Request::is('*/ing_vhiculo/ingreso_vehiculo/*')) {
            Route::bind('ingreso_vehiculo', function ($ingreso_vehiculo) {
                $ingreso_vehiculorepo = $this->app->make('Olger\IngVhiculo\Interfaces\IngresoVehiculoRepositoryInterface');
                return $ingreso_vehiculorepo->findorNew($ingreso_vehiculo);
            });
        }
        if (Request::is('*/ing_vhiculo/foto/*')) {
            Route::bind('foto', function ($foto) {
                $fotorepo = $this->app->make('Olger\IngVhiculo\Interfaces\FotoRepositoryInterface');
                return $fotorepo->findorNew($foto);
            });
        }
        if (Request::is('*/ing_vhiculo/factura/*')) {
            Route::bind('factura', function ($factura) {
                $facturarepo = $this->app->make('Olger\IngVhiculo\Interfaces\FacturaRepositoryInterface');
                return $facturarepo->findorNew($factura);
            });
        }
        if (Request::is('*/ing_vhiculo/detalle_facturas/*')) {
            Route::bind('detalle_facturas', function ($detalle_facturas) {
                $detalle_facturasrepo = $this->app->make('Olger\IngVhiculo\Interfaces\DetalleFacturasRepositoryInterface');
                return $detalle_facturasrepo->findorNew($detalle_facturas);
            });
        }
        if (Request::is('*/ing_vhiculo/info_facturas/*')) {
            Route::bind('info_facturas', function ($info_facturas) {
                $info_facturasrepo = $this->app->make('Olger\IngVhiculo\Interfaces\InfoFacturasRepositoryInterface');
                return $info_facturasrepo->findorNew($info_facturas);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
